@@ -18,16 +18,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
-
 import os
 import signal
 from subprocess import PIPE, STDOUT, Popen
 
-import six
 from dagster import check
 from dagster.utils import safe_tempfile_path
 
+OUTPUT_LOGGING_OPTIONS = ["STREAM", "BUFFER", "NONE"]
+
 
 def execute_script_file(shell_script_path, output_logging, log, cwd=None, env=None):
     """Execute a shell script file specified by the argument ``shell_command``. The script will be
@@ -46,7 +45,7 @@ def execute_script_file(shell_script_path, output_logging, log, cwd=None, env=No
             Unused by default.
 
     Raises:
-        Exception: When an invalid output_logging is selected. Unreachable from solid-based
+        Exception: When an invalid output_logging is selected. Unreachable from op-based
             invocation since the config system will check output_logging against the config
             enum.
 
@@ -58,6 +57,9 @@ def execute_script_file(shell_script_path, output_logging, log, cwd=None, env=No
     check.opt_str_param(cwd, "cwd", default=os.path.dirname(shell_script_path))
     env = check.opt_dict_param(env, "env")
 
+    if output_logging not in OUTPUT_LOGGING_OPTIONS:
+        raise Exception("Unrecognized output_logging %s" % output_logging)
+
     def pre_exec():
         # Restore default signal disposition and invoke setsid
         for sig in ("SIGPIPE", "SIGXFZ", "SIGXFSZ"):
@@ -66,49 +68,51 @@ def execute_script_file(shell_script_path, output_logging, log, cwd=None, env=No
         os.setsid()
 
     with open(shell_script_path, "rb") as f:
-        shell_command = six.ensure_str(f.read())
+        shell_command = f.read().decode("utf-8")
 
-    log.info("Running command:\n{command}".format(command=shell_command))
+    log.info(f"Running command:\n{shell_command}")
 
     # pylint: disable=subprocess-popen-preexec-fn
-    sub_process = Popen(
-        ["bash", shell_script_path],
-        stdout=PIPE,
-        stderr=STDOUT,
-        cwd=cwd,
-        env=env,
-        preexec_fn=pre_exec,
-    )
+    sub_process = None
+    try:
+        stdout_pipe = PIPE
+        stderr_pipe = STDOUT
+        if output_logging == "NONE":
+            stdout_pipe = stderr_pipe = None
 
-    # Will return the string result of reading stdout of the shell command
-    output = ""
-
-    if output_logging not in ["STREAM", "BUFFER", "NONE"]:
-        raise Exception("Unrecognized output_logging %s" % output_logging)
-
-    # Stream back logs as they are emitted
-    if output_logging == "STREAM":
-        for raw_line in iter(sub_process.stdout.readline, b""):
-            line = six.ensure_str(raw_line)
-            log.info(line.rstrip())
-            output += line
-
-    sub_process.wait()
-
-    # Collect and buffer all logs, then emit
-    if output_logging == "BUFFER":
-        output = "".join(
-            [six.ensure_str(raw_line) for raw_line in iter(sub_process.stdout.readline, b"")]
+        sub_process = Popen(
+            ["bash", shell_script_path],
+            stdout=stdout_pipe,
+            stderr=stderr_pipe,
+            cwd=cwd,
+            env=env,
+            preexec_fn=pre_exec,
+            encoding="UTF-8",
         )
-        log.info(output)
 
-    # no logging in this case
-    elif output_logging == "NONE":
-        pass
+        log.info(f"Command pid: {sub_process.pid}")
 
-    log.info("Command exited with return code {retcode}".format(retcode=sub_process.returncode))
+        output = ""
+        if output_logging == "STREAM":
+            # Stream back logs as they are emitted
+            lines = []
+            for line in sub_process.stdout:
+                log.info(line.rstrip())
+                lines.append(line)
+            output = "".join(lines)
+        elif output_logging == "BUFFER":
+            # Collect and buffer all logs, then emit
+            output, _ = sub_process.communicate()
+            log.info(output)
 
-    return output, sub_process.returncode
+        sub_process.wait()
+        log.info("Command exited with return code {retcode}".format(retcode=sub_process.returncode))
+
+        return output, sub_process.returncode
+    finally:
+        # Always terminate subprocess, including in cases where the pipeline run is terminated
+        if sub_process:
+            sub_process.terminate()
 
 
 def execute(shell_command, output_logging, log, cwd=None, env=None):
@@ -138,7 +142,7 @@ def execute(shell_command, output_logging, log, cwd=None, env=None):
         log.info("Using temporary directory: %s" % tmp_path)
 
         with open(tmp_file_path, "wb") as tmp_file:
-            tmp_file.write(six.ensure_binary(shell_command))
+            tmp_file.write(shell_command.encode("utf-8"))
             tmp_file.flush()
             script_location = os.path.abspath(tmp_file.name)
             log.info("Temporary script location: {location}".format(location=script_location))
